@@ -17,20 +17,20 @@ import zipfile
 from distutils import log
 from distutils.errors import DistutilsOptionError, DistutilsPlatformError
 from distutils.sysconfig import get_config_h_filename, get_config_var
-from distutils.util import convert_path
+from distutils.util import convert_path, get_platform
 from itertools import chain
 
-import pkg_resources
-from setuptools import Command
-
 import macholib.dyld
 import macholib.MachO
 import macholib.MachOStandalone
-from macholib.util import flipwritable
+import pkg_resources
+from macholib.util import flipwritable, is_platform_file
 from modulegraph import modulegraph, zipio
 from modulegraph.find_modules import find_modules, find_needed_modules, parse_mf_results
 from modulegraph.modulegraph import Package, Script, SourceModule
 from modulegraph.util import imp_find_module
+from setuptools import Command
+
 from py2app import recipes
 from py2app.apptemplate.setup import main as script_executable
 from py2app.create_appbundle import create_appbundle
@@ -38,6 +38,7 @@ from py2app.create_pluginbundle import create_pluginbundle
 from py2app.filters import has_filename_filter, not_stdlib_filter
 from py2app.util import (
     byte_compile,
+    codesign_adhoc,
     copy_file,
     copy_resource,
     copy_tree,
@@ -89,6 +90,22 @@ else:
     sys_base_prefix = sys.prefix
 
 
+def loader_paths(sourcefn, destfn):
+    # Yield (sourcefn, destfn) pairs for all
+    # '@loader_path' load commands in 'sourcefn'
+    sourcedir = os.path.dirname(sourcefn)
+    destdir = os.path.dirname(destfn)
+
+    m = macholib.MachO.MachO(sourcefn)
+    for header in m.headers:
+        for _idx, _name, other in header.walkRelocatables():
+            if not other.startswith("@loader_path/"):
+                continue
+            relpath = other[13:]
+            yield os.path.join(sourcedir, relpath), os.path.join(destdir, relpath)
+
+        
+
 def rewrite_tkinter_load_commands(tkinter_path):
     print("rewrite_tk", tkinter_path)
     m = macholib.MachO.MachO(tkinter_path)
@@ -209,6 +226,7 @@ class PythonStandalone(macholib.MachOStandalone.MachOStandalone):
             )
             self.ext_map[fn] = os.path.dirname(e.filename)
 
+
     def update_node(self, m):
         if isinstance(m, macholib.MachO.MachO):
             if m.filename in self.ext_map:
@@ -1051,6 +1069,10 @@ class py2app(Command):
                 mergecopy(src_fn, tgt_fn)
                 make_exec(tgt_fn)
 
+            arch = self.arch if self.arch is not None else get_platform().split("-")[-1]
+            if arch in ("universal2", "arm64"):
+                codesign_adhoc(target.appdir)
+
     def collect_recipedict(self):
         return dict(iterRecipes())
 
@@ -1630,9 +1652,15 @@ class py2app(Command):
                 for fmwk in self.frameworks:
                     mm.mm.run_file(fmwk)
                 platfiles = mm.run()
+
                 if self.strip:
                     platfiles = self.strip_dsym(platfiles)
                     self.strip_files(platfiles)
+
+                arch = self.arch if self.arch is not None else get_platform().split("-")[-1]
+               
+                if arch in ("universal2", "arm64"):
+                    codesign_adhoc(target.appdir)
             self.app_files.append(dst)
 
     def copy_package_data(self, package, target_dir):
@@ -2065,7 +2093,11 @@ class py2app(Command):
         if self.runtime_preferences and use_runtime_preference:
             self.plist.setdefault("PyRuntimeLocations", self.runtime_preferences)
         appdir, plist = create_pluginbundle(
-            appdir, appname, plist=self.plist, extension=self.extension, arch=self.arch,
+            appdir,
+            appname,
+            plist=self.plist,
+            extension=self.extension,
+            arch=self.arch,
         )
         appdir = fsencoding(appdir)
         resdir = os.path.join(appdir, "Contents", "Resources")
@@ -2196,6 +2228,21 @@ class py2app(Command):
         target.appdir = appdir
         return appdir
 
+    def copy_loader_paths(self, sourcefn, destfn):
+        todo = [(sourcefn, destfn)]
+    
+        while todo:
+            next = []
+            for item in todo:
+                for s, d in loader_paths(*item):
+                    if os.path.exists(d): continue
+                    next.append((s, d))
+                    if not self.dry_run:
+                       if not os.path.exists(os.path.dirname(d)):
+                          os.makedirs(os.path.dirname(d))
+                    copy_file(s, d, dry_run=self.dry_run)
+            todo = next
+
     def build_executable(
         self, target, arcname, pkgexts, copyexts, script, extra_scripts
     ):
@@ -2359,6 +2406,11 @@ class py2app(Command):
             self.mkpath(os.path.dirname(fn))
             copy_file(copyext.filename, fn, dry_run=self.dry_run)
 
+            # MachoStandalone does not support '@loader_path' (and cannot in its
+            # current form). Check for "@loader_path" in the load commands of 
+            # the extension and copy those files into the bundle as well.
+            self.copy_loader_paths(copyext.filename, fn)
+
         for src, dest in self.iter_data_files():
             dest = os.path.join(resdir, dest)
             if src == dest:
