@@ -5,30 +5,42 @@ This is stripped down and customized for use in py2app applications
 """
 
 import sys
+
 # os is actually in the zip, so we need to do this here.
 # we can't call it python24.zip because zlib is not a built-in module (!)
-_libdir = '/lib/python' + sys.version[:3]
-_parent = '/'.join(__file__.split('/')[:-1])
+_libdir = "/lib/python" + sys.version[:3]
+_parent = "/".join(__file__.split("/")[:-1])
 if not _parent.endswith(_libdir):
     _parent += _libdir
-sys.path.append(_parent + '/site-packages.zip')
+sys.path.append(_parent + "/site-packages.zip")
 
 # Stuffit decompresses recursively by default, that can mess up py2app bundles,
 # add the uncompressed site-packages to the path to compensate for that.
-sys.path.append(_parent + '/site-packages')
+sys.path.append(_parent + "/site-packages")
+
+USER_SITE = None
+
+
+def _import_os():
+    global os
+    import os  # noqa: E402
+
+
+_import_os()
 
-import os
 try:
     basestring
 except NameError:
     basestring = str
 
+
 def makepath(*paths):
     dir = os.path.abspath(os.path.join(*paths))
     return dir, os.path.normcase(dir)
 
+
 for m in sys.modules.values():
-    f = getattr(m, '__file__', None)
+    f = getattr(m, "__file__", None)
     if isinstance(f, basestring) and os.path.exists(f):
         m.__file__ = os.path.abspath(m.__file__)
 del m
@@ -43,13 +55,14 @@ for dir in sys.path:
     # if they only differ in case); turn relative paths into absolute
     # paths.
     dir, dircase = makepath(dir)
-    if not dircase in _dirs_in_sys_path:
+    if dircase not in _dirs_in_sys_path:
         L.append(dir)
         _dirs_in_sys_path[dircase] = 1
 sys.path[:] = L
 del dir, dircase, L
 _dirs_in_sys_path = None
 
+
 def _init_pathinfo():
     global _dirs_in_sys_path
     _dirs_in_sys_path = d = {}
@@ -59,6 +72,7 @@ def _init_pathinfo():
         dir, dircase = makepath(dir)
         d[dircase] = 1
 
+
 def addsitedir(sitedir):
     global _dirs_in_sys_path
     if _dirs_in_sys_path is None:
@@ -67,8 +81,8 @@ def addsitedir(sitedir):
     else:
         reset = 0
     sitedir, sitedircase = makepath(sitedir)
-    if not sitedircase in _dirs_in_sys_path:
-        sys.path.append(sitedir)        # Add path component
+    if sitedircase not in _dirs_in_sys_path:
+        sys.path.append(sitedir)  # Add path component
     try:
         names = os.listdir(sitedir)
     except os.error:
@@ -80,6 +94,7 @@ def addsitedir(sitedir):
     if reset:
         _dirs_in_sys_path = None
 
+
 def addpackage(sitedir, name):
     global _dirs_in_sys_path
     if _dirs_in_sys_path is None:
@@ -94,15 +109,15 @@ def addpackage(sitedir, name):
                 dir = f.readline()
                 if not dir:
                     break
-                if dir[0] == '#':
+                if dir[0] == "#":
                     continue
                 if dir.startswith("import"):
                     exec(dir)
                     continue
-                if dir[-1] == '\n':
+                if dir[-1] == "\n":
                     dir = dir[:-1]
                 dir, dircase = makepath(sitedir, dir)
-                if not dircase in _dirs_in_sys_path and os.path.exists(dir):
+                if dircase not in _dirs_in_sys_path and os.path.exists(dir):
                     sys.path.append(dir)
                     _dirs_in_sys_path[dircase] = 1
     except IOError:
@@ -111,13 +126,11 @@ def addpackage(sitedir, name):
         _dirs_in_sys_path = None
 
 
-#sys.setdefaultencoding('utf-8')
-
 #
 # Run custom site specific code, if available.
 #
 try:
-    import sitecustomize
+    import sitecustomize  # noqa: F401
 except ImportError:
     pass
 
