@@ -1,7 +1,5 @@
 def check(cmd, mf):
-    m = mf.findNode('numpy')
+    m = mf.findNode("numpy")
     if m is None or m.filename is None:
         return None
-    return dict(
-        packages=['numpy']
-    )
+    return {"packages": ["numpy"]}
