@@ -2,9 +2,8 @@
 # Recipe to copy Tcl/Tk support libraries when Python is linked
 # with a regular unix install instead of a framework install.
 #
-import sys
-import macholib
 import os
+import sys
 import textwrap
 
 try:
@@ -14,27 +13,32 @@ except ImportError:
 
 
 def check(cmd, mf):
-    m = mf.findNode('_tkinter')
+    m = mf.findNode("_tkinter")
     if m is None:
         return None
 
-    prefix = sys.prefix if not hasattr(sys, 'real_prefix') else sys.real_prefix
+    prefix = sys.prefix if not hasattr(sys, "real_prefix") else sys.real_prefix
 
     paths = []
-    lib = os.path.join(prefix, 'lib')
+    lib = os.path.join(prefix, "lib")
     for fn in os.listdir(lib):
         if not os.path.isdir(os.path.join(lib, fn)):
             continue
 
-        if fn.startswith('tk'):
+        if fn.startswith("tk"):
             tk_path = fn
             paths.append(os.path.join(lib, fn))
 
-        elif fn.startswith('tcl'):
+        elif fn.startswith("tcl"):
             tcl_path = fn
             paths.append(os.path.join(lib, fn))
 
-    prescript = textwrap.dedent("""\
+    if not paths:
+        return None
+
+    prescript = (
+        textwrap.dedent(
+            """\
         def _boot_tkinter():
             import os
 
@@ -42,6 +46,9 @@ def check(cmd, mf):
             os.putenv("TCL_LIBRARY", os.path.join(resourcepath, "lib/%(tcl_path)s"))
             os.putenv("TK_LIBRARY", os.path.join(resourcepath, "lib/%(tk_path)s"))
         _boot_tkinter()
-        """) % dict(tcl_path=tcl_path, tk_path=tk_path)
+        """
+        )
+        % {"tcl_path": tcl_path, "tk_path": tk_path}
+    )
 
-    return dict(resources=[('lib', paths)], prescripts=[StringIO(prescript)])
+    return {"resources": [("lib", paths)], "prescripts": [StringIO(prescript)]}
