@@ -10,9 +10,9 @@ import warnings
 import zipfile
 from distutils import log
 
-import pkg_resources
-
 import macholib.util
+import pkg_resources
+from macholib.util import is_platform_file
 from modulegraph import zipio
 from modulegraph.find_modules import PY_SUFFIXES
 
@@ -238,7 +238,7 @@ def find_version(fn):
     """
     return "0.0.0"
     import compiler
-    from compiler.ast import Module, Stmt, Assign, AssName, Const
+    from compiler.ast import Assign, AssName, Const, Module, Stmt
 
     ast = compiler.parseFile(fn)
     if not isinstance(ast, Module):
@@ -387,8 +387,8 @@ def byte_compile(
     # "Indirect" byte-compilation: write a temporary script and then
     # run it with the appropriate flags.
     if not direct:
-        from tempfile import mktemp
         from distutils.util import execute, spawn
+        from tempfile import mktemp
 
         script_name = mktemp(".py")
         if verbose:
@@ -441,8 +441,8 @@ byte_compile(files, optimize=%r, force=%r,
         )
 
     else:
-        from py_compile import compile
         from distutils.dir_util import mkpath
+        from py_compile import compile
 
         for mod in py_files:
             # Terminology from the py_compile module:
@@ -540,6 +540,7 @@ skipjunk = skipfunc(JUNK, JUNK_EXTS)
 def get_magic(platform=sys.platform):
     if platform == "darwin":
         import struct
+
         import macholib.mach_o
 
         return [
@@ -610,10 +611,10 @@ def copy_tree(
     assert isinstance(src, (str, unicode)), repr(src)
     assert isinstance(dst, (str, unicode)), repr(dst)
 
-    from distutils.dir_util import mkpath
-    from distutils.dep_util import newer
-    from distutils.errors import DistutilsFileError
     from distutils import log
+    from distutils.dep_util import newer
+    from distutils.dir_util import mkpath
+    from distutils.errors import DistutilsFileError
 
     src = fsencoding(src)
     dst = fsencoding(dst)
@@ -771,3 +772,60 @@ def momc(src, dst):
 
 def mapc(src, dst):
     subprocess.check_call([_get_tool("mapc"), src, dst])
+
+
+def _macho_find(path):
+    for basename, _dirs, files in os.walk(path):
+        for fn in files:
+            path = os.path.join(basename, fn)
+            if is_platform_file(path):
+                yield path
+
+
+def _dosign(*path):
+    subprocess.check_call(
+        (
+	    "codesign",
+	        "-s",
+	    "-",
+	    "--preserve-metadata=identifier,entitlements,flags,runtime",
+	    "-f",
+        ) + path
+    )
+
+def codesign_adhoc(bundle):
+    """
+    (Re)sign a bundle
+
+    Signing should be done "depth-first", sign 
+    libraries before signing the libraries/executables 
+    linking to them.
+
+    The current implementation is a crude hack,
+    but is better than nothing. Signing properly requires
+    performing a topological sort using dependencies.
+
+    "codesign" will resign the entire bundle, but only
+    if partial signatures are valid.
+    """
+    #try:
+    #    _dosign(bundle)
+    #    return
+    #except subprocess.CalledProcessError:
+    #    pass
+
+    platfiles = list(_macho_find(bundle))
+    print("sign", platfiles)
+    while platfiles:
+        for file in platfiles:
+            failed = []
+            try:
+                _dosign(file)
+            except subprocess.CalledProcessError:
+                failed.append(file)
+        if failed == platfiles:
+            raise RuntimeError("Cannot sign bundle %r"%(bundle,))
+        platfiles = failed
+    
+
+    _dosign(bundle)
