@@ -12,13 +12,19 @@ def import_module(name):
         print ("* import failed")
 
     else:
-        for k in name.split('.')[1:]:
-            m = getattr(m, k)
+        #for k in name.split('.')[1:]:
+        #    m = getattr(m, k)
         print (m.__name__)
 
 def print_path():
     print(sys.path)
 
+def run_python():
+    import subprocess
+
+    p = subprocess.Popen([sys.executable, '-c', 'print("ok")'])
+    p.wait()
+
 while True:
     line = sys.stdin.readline()
     if not line:
